@@ -14,6 +14,7 @@ import traceback
 from . import C2ProfileBase
 from importlib import import_module, invalidate_caches
 from functools import partial
+from .config import settings
 
 credentials = None
 connection_params = None
@@ -25,7 +26,7 @@ output = ""
 exchange = None
 container_files_path = None
 
-container_version = "2"
+container_version = "3"
 
 
 def deal_with_stdout():
@@ -258,6 +259,11 @@ async def get_file(request):
     }
 
 
+async def exit_container(request):
+    print_flush("[-] Container tasked to exit...")
+    sys.exit(1)
+
+
 async def write_file(request):
     global container_files_path
     global running
@@ -319,7 +325,7 @@ async def rabbit_c2_rpc_callback(
             )
 
 
-async def connect_and_consume_rpc(main_config: dict, debug):
+async def connect_and_consume_rpc(debug):
     connection = None
     global hostname
     while connection is None:
@@ -327,10 +333,10 @@ async def connect_and_consume_rpc(main_config: dict, debug):
             if debug:
                 print_flush("Connecting to rabbitmq in connect_and_consume_rpc")
             connection = await aio_pika.connect_robust(
-                host=main_config["host"],
-                login=main_config["username"],
-                password=main_config["password"],
-                virtualhost=main_config["virtual_host"]
+                host=settings.get("host", "127.0.0.1"),
+                login=settings.get("username", "mythic_user"),
+                password=settings.get("password", "mythic_password"),
+                virtualhost=settings.get("virtual_host", "mythic_vhost"),
             )
             if debug:
                 print_flush("Successfully connected in connect_and_consume_rpc")
@@ -378,7 +384,7 @@ async def rabbit_mythic_c2_rpc_callback(
             sys.stdout.flush()
 
 
-async def connect_and_consume_mythic_rpc(main_config: dict, debug):
+async def connect_and_consume_mythic_rpc(debug):
     connection = None
     global hostname
     while connection is None:
@@ -386,10 +392,10 @@ async def connect_and_consume_mythic_rpc(main_config: dict, debug):
             if debug:
                 print_flush("Connecting to rabbitmq in connect_and_consume_mythic_rpc")
             connection = await aio_pika.connect_robust(
-                host=main_config["host"],
-                login=main_config["username"],
-                password=main_config["password"],
-                virtualhost=main_config["virtual_host"]
+                host=settings.get("host", "127.0.0.1"),
+                login=settings.get("username", "mythic_user"),
+                password=settings.get("password", "mythic_password"),
+                virtualhost=settings.get("virtual_host", "mythic_vhost"),
             )
             if debug:
                 print_flush("Successfully connected in connect_and_consume_mythic_rpc")
@@ -410,6 +416,8 @@ async def connect_and_consume_mythic_rpc(main_config: dict, debug):
         task = await queue.consume(
             partial(rabbit_mythic_c2_rpc_callback, channel.default_exchange)
         )
+        # wait to sync classes with mythic until we have a way to get messages back
+        await sync_classes()
         result = await asyncio.wait_for(task, None)
     except Exception as e:
         print_flush("Exception in connect_and_consume_mythic_rpc .consume: {}".format(str(e)))
@@ -420,15 +428,11 @@ async def mythic_service(debug: bool):
     global exchange
     global container_files_path
     connection = None
-    config_file = open("rabbitmq_config.json", "rb")
-    main_config = json.loads(config_file.read().decode("utf-8"))
-    config_file.close()
-    if main_config["name"] == "hostname":
+    hostname = settings.get("name", "hostname")
+    if hostname == "hostname":
         hostname = socket.gethostname()
-    else:
-        hostname = main_config["name"]
     container_files_path = pathlib.Path(
-        os.path.abspath(main_config["container_files_path"])
+        os.path.abspath(settings.get("container_files_path", "/Mythic/"))
     )
     container_files_path = container_files_path / "c2_code"
     while connection is None:
@@ -436,10 +440,10 @@ async def mythic_service(debug: bool):
             if debug:
                 print_flush("Connecting to rabbitmq from mythic_service")
             connection = await aio_pika.connect_robust(
-                host=main_config["host"],
-                login=main_config["username"],
-                password=main_config["password"],
-                virtualhost=main_config["virtual_host"],
+                host=settings.get("host", "127.0.0.1"),
+                login=settings.get("username", "mythic_user"),
+                password=settings.get("password", "mythic_password"),
+                virtualhost=settings.get("virtual_host", "mythic_vhost"),
             )
             if debug:
                 print_flush("Successfully connected to rabbitmq from mythic_service")
@@ -466,12 +470,12 @@ async def mythic_service(debug: bool):
         if debug:
             print_flush("Creating task to consume in mythic_service")
         task = queue.consume(callback)
-        await sync_classes()
+        
         print("Listening for c2.modify.{}.#".format(hostname))
         if debug:
             print_flush("Creating task for connect_and_consume_rpc from mythic_service")
-        task4 = asyncio.ensure_future(connect_and_consume_rpc(main_config, debug))
-        task5 = asyncio.ensure_future(connect_and_consume_mythic_rpc(main_config, debug))
+        task4 = asyncio.ensure_future(connect_and_consume_rpc(debug))
+        task5 = asyncio.ensure_future(connect_and_consume_mythic_rpc(debug))
         if debug:
             print_flush("Waiting for all tasks to finish in mythic_service")
         result = await asyncio.gather(task, task4, task5)
@@ -482,22 +486,18 @@ async def mythic_service(debug: bool):
 
 async def heartbeat_loop(debug: bool):
     connection = None
-    config_file = open("rabbitmq_config.json", "rb")
-    main_config = json.loads(config_file.read().decode("utf-8"))
-    config_file.close()
-    if main_config["name"] == "hostname":
+    hostname = settings.get("name", "hostname")
+    if hostname == "hostname":
         hostname = socket.gethostname()
-    else:
-        hostname = main_config["name"]
     while connection is None:
         try:
             if debug:
                 print_flush("Connecting to rabbitmq from heartbeat_loop")
             connection = await aio_pika.connect_robust(
-                host=main_config["host"],
-                login=main_config["username"],
-                password=main_config["password"],
-                virtualhost=main_config["virtual_host"],
+                host=settings.get("host", "127.0.0.1"),
+                login=settings.get("username", "mythic_user"),
+                password=settings.get("password", "mythic_password"),
+                virtualhost=settings.get("virtual_host", "mythic_vhost"),
             )
             if debug:
                 print_flush("Successfully connected to rabbitmq from heartbeat_loop")
@@ -535,3 +535,6 @@ def start_service_and_heartbeat(debug=False):
     loop = asyncio.get_event_loop()
     asyncio.gather(mythic_service(debug), heartbeat_loop(debug))
     loop.run_forever()
+
+def get_version_info():
+    print_flush("[*] Mythic C2 Profile Version: " + container_version)
